@@ -26,6 +26,14 @@ Global Configuration
 
    Default: ``"sqlite"``
 
+.. py:data:: ddtrace.config.sqlite["trace_fetch_methods"]
+
+   Whether or not to trace fetch methods.
+
+   Can also configured via the ``DD_SQLITE_TRACE_FETCH_METHODS`` environment variable.
+
+   Default: ``False``
+
 
 Instance Configuration
 ~~~~~~~~~~~~~~~~~~~~~~
