@@ -1,8 +1,9 @@
 from __future__ import division
 
 import threading
+from typing import Optional
 
-from .. import compat
+from ..internal import compat
 
 
 class RateLimiter(object):
@@ -23,6 +24,7 @@ class RateLimiter(object):
     )
 
     def __init__(self, rate_limit):
+        # type: (int) -> None
         """
         Constructor for RateLimiter
 
@@ -33,19 +35,20 @@ class RateLimiter(object):
         :type rate_limit: :obj:`int`
         """
         self.rate_limit = rate_limit
-        self.tokens = rate_limit
+        self.tokens = rate_limit  # type: float
         self.max_tokens = rate_limit
 
         self.last_update = compat.monotonic()
 
-        self.current_window = 0
+        self.current_window = 0  # type: float
         self.tokens_allowed = 0
         self.tokens_total = 0
-        self.prev_window_rate = None
+        self.prev_window_rate = None  # type: Optional[float]
 
         self._lock = threading.Lock()
 
     def is_allowed(self):
+        # type: () -> bool
         """
         Check whether the current request is allowed or not
 
@@ -61,6 +64,7 @@ class RateLimiter(object):
         return allowed
 
     def _update_rate_counts(self, allowed):
+        # type: (bool) -> None
         now = compat.monotonic()
 
         # No tokens have been seen yet, start a new window
@@ -81,6 +85,7 @@ class RateLimiter(object):
         self.tokens_total += 1
 
     def _is_allowed(self):
+        # type: () -> bool
         # Rate limit of 0 blocks everything
         if self.rate_limit == 0:
             return False
@@ -100,6 +105,7 @@ class RateLimiter(object):
             return False
 
     def _replenish(self):
+        # type: () -> None
         # If we are at the max, we do not need to add any more
         if self.tokens == self.max_tokens:
             return
@@ -116,6 +122,7 @@ class RateLimiter(object):
         )
 
     def _current_window_rate(self):
+        # type: () -> float
         # No tokens have been seen, effectively 100% sample rate
         # DEV: This is to avoid division by zero error
         if not self.tokens_total:
@@ -126,6 +133,7 @@ class RateLimiter(object):
 
     @property
     def effective_rate(self):
+        # type: () -> float
         """
         Return the effective sample rate of this rate limiter
 
